pub struct ScanResult { /* private fields */ }Expand description
Result of ArrowReader::read, containing the
record batch stream and metrics collected during the scan.
Implementations
Sourceimpl ScanResult
impl ScanResult
Sourcepub fn stream(self) -> ArrowRecordBatchStream
pub fn stream(self) -> ArrowRecordBatchStream
Consumes the result, returning only the record batch stream.
Sourcepub fn metrics(&self) -> &ScanMetrics
pub fn metrics(&self) -> &ScanMetrics
Returns a reference to the scan metrics.